import React, { useEffect, useRef, useState } from 'react'
import Taro from '@tarojs/taro'

export default props => {
  const id = useRef(`vlist-${Math.random().toString(36).substring(2)}`)

  const [width, setWidth] = useState()
  const [height, setHeight] = useState()
  
  const hanldeScrollToLower = e => {
    if ((props.list || []).length >= (props.total - 0)) {
      return
    }

    if (props.onScrollToLower) {
      props.onScrollToLower(e)
    }
  }
  

  useEffect(() => {
    let sysInfo = {}
    if (!props.width || !props.height) {
      sysInfo = Taro.getSystemInfoSync()
    }

    if (!props.width) {
      setWidth(sysInfo.safeArea.width)
    } else {
      setWidth(props.width)
    }

    if (!props.height) {
      setHeight(sysInfo.safeArea.height)
    } else {
      setHeight(props.height)
    }
  }, [props.width, props.height])

  return (
    <recycle-view
      id={id.current}
      width={width}
      height={height}
      lower-threshold={props.lowerThreshold || 50}
      upper-threshold={props.upperThreshold || 50}
      onScroll={props.onScroll}
      onScrollToLower={hanldeScrollToLower}
      onScrollToUpper={props.onScrollToUpper}
      scroll-top={true}
      scroll-y={true}
      batch="{{batchSetRecycleData}}"
      enable-back-to-top={true}
    >
      {
        props.before && <view slot="before">{props.before}</view>
      }
      {
        (props.list || []).map((item, inx) => (
          <recycle-item key={props.dataKey? item[props.dataKey] : inx}>
            {props.renderItem(item)}
          </recycle-item>
        ))
      }
      {
        props.after && <view slot="after">{props.after}</view>
      }      
    </recycle-view>
  )
}
