import React, { useEffect, useState } from 'react'
import './register.scss'
import { View, Text, Input } from '@tarojs/components'
import ContainerLayout from '../../../compents/container/index'
// import { AtInput } from 'taro-ui'
import Tab from '../../../compents/tab'
import Layout from '../../../layout'
import request from '@/util/request'


const InputGroup = props => {
  const [name, setName] = useState(props.dataSource.name)
  const [phone, setPhone] = useState(props.dataSource.phone)

  useEffect(() => {
    if (name !== props.dataSource.name) {
      setName(props.dataSource.name)
    }
  }, [props.dataSource.name])
  
  useEffect(() => {
    if (phone !== props.dataSource.phone) {
      setPhone(props.dataSource.phone)
    }
  }, [props.dataSource.phone])

  const handeNameChange = e => {
    const v = e.detail.value
    setName(v)
    if (props.onChange) {
      props.onChange({
        name: v,
        phone
      })
    }
    return v
  }
  
  const handePhoneChange = e => {
    const v = e.detail.value
    setPhone(v)
    if (props.onChange) {
      props.onChange({
        name,
        phone: v
      })
    }
    return v
  }

  const handleFocues = (_, e) => {
    e.stopPropagation()
    e.preventDefault()
  }

  return (
    <View className='register-user'>
      <Text>入住人{props.index+1}</Text>
      <ContainerLayout className='register-user-from'>
        {console.log(name,phone,'name,phone')}
        <Input name="name" className='register-user-from-input' value={name} onInput={handeNameChange} placeholder='姓名' type='text' />
        <Input name="phone" className='register-user-from-input' value={phone} onInput={handePhoneChange} placeholder='电话' type='text' />
      </ContainerLayout>
    </View>
  )
}

const register = (props) => {

  let [list, setList] = useState([])
  useEffect(() => {
    if (props.dataSource) {
      const {personNum} = props.dataSource.houseSetting || {}

      setList(new Array(personNum || 0).fill('*').map(x => ({name: undefined, phone: undefined})))
    }
  }, [props.dataSource])

  const onClick = () => {
    const hasNull = list.filter(x => !x.name || !x.phone)[0]
    if (hasNull) {
      Taro.showModal({
        title: '请将信息填写完成',
        showCancel: false,
        success: () => {}
      })

      return
    }

    const data = {
      orderId: props.dataSource.orderId,
      houseId: props.dataSource.houseSetting.houseId,
      personList: list,
    }

    request({ url: '/taHousePerson', method: 'POST', data }).then(res => {
      if (props.onFinished) {
        props.onFinished(res)
      }
    }).catch(err => {
      console.error(err)
      const message = err.message || err.errMsg || err
      Taro.showToast({
        title: message,
        icon: 'none',
        duration: 3000
      })
    })
  }

  const onChangeList = index => value =>  { 
    list[index] = value
    setList([...list])
  }

  return <View className='register' >
    <Layout>
      {list.map((x, index) => {
        let inx = index
        return <InputGroup key={inx} index={index} dataSource={x} onChange={onChangeList(inx)} />
      })}
    </Layout>

    <Tab value={['开启旅程']} onClick={(e) => onClick(e)}></Tab>
  </View>
}

export default register