import React, { useEffect, useMemo, useState, forwardRef, useImperativeHandle } from 'react'
import Taro, { useDidShow } from '@tarojs/taro'
import './index.scss'
import { View, Text, Input, Image } from '@tarojs/components'
import ContainerLayout from '../../../compents/container/index'
import radio from '../../../assets/radio.png'
import request from '@/util/request'
import RecycleList from '@/compents/RecycleList'


let house = (props, ref) => {

  const [list, setList] = useState([])
  const [radioHouse, setRadioHouse] = useState()
  const [width, setWidth] = useState()
  // const [height, setHeight] = useState()
  const [queryParams, setQueryParams] = useState({pageNum: 1, pageSize: 10})
  const [total, setTotal] = useState(0)

  useImperativeHandle(ref, () => ({
    // changeVal 就是暴露给父组件的方法
    getRefHouseList: () => {
      getHouseList()
    }
  }));

  const radioHouseState = useMemo(() => props.radioHouseState, [props.radioHouseState])

  wx.setNavigationBarTitle({
    title: '民宿房源管理'
  })


  const getHouseList = () => {
    request({
      url: '/taHouse',
      params: queryParams
    }).then((res) => {
      const { records, ...page } = res.data.data

      if (page.current !== 1) {
        setList(list.concat(records))
      } else {
        setList(records)
      }
      setTotal(page.total)
    })
  }

  const handleScrollBottom = e => {
    setQueryParams({
      ...queryParams,
      pageNum: queryParams.pageNum + 1
    })
  }

  const onShare = (x) => {
    Taro.navigateTo({ url: `/pages/share/index?houseId=${x.houseId}` })
  }

  useEffect(() => {
    console.log(props, ref,'props, ref')
    getHouseList()

    Taro.nextTick(() => {

      Taro.createSelectorQuery()
        .selectAll('.houselist')
        .boundingClientRect(res => {
          if (res) {
            setWidth(res[0].width)
            // setHeight(res[0].height)
          }
        }).exec()
    })

  }, [])

  useEffect(() => {
    getHouseList()
  }, [queryParams])

  useDidShow(() => {
    setQueryParams({ ...queryParams })
  })

  return (
    <View className='houselist'>
       {
        (!list || !list.length) && < View className='nodata'> 暂无数据</View>
      }
      <RecycleList
        height={508}
        width={width}
        list={list}
        total={total}
        dataKey="houseId"
        onScrollToLower={handleScrollBottom}
        renderItem={x => (
          <View className='houselist-view'>
            {/* <Text className='houselist-view-title'>房源编号：{x.houseId}</Text> */}
            <ContainerLayout className='houselist-view-card'>
              {radioHouseState && <View className='houselist-view-card-radio' onClick={() => { props.onChange(x), setRadioHouse(x) }}>
                {radioHouse?.houseId == x?.houseId && <Image src={radio} style={{ width: '30rpx', height: '20rpx' }}></Image>}
              </View>}
              <View className='top' onClick={() => { if (!radioHouseState) Taro.navigateTo({ url: `/pages/house/index?houseId=${x.houseId}` }) }}>{x.title}</View>
              <View className='bottom'>
                <Text onClick={() => { if (!radioHouseState) Taro.navigateTo({ url: `/pages/house/household/index?houseId=${x.houseId}` }) }}>查看入住人</Text>
                <Text onClick={()=>onShare(x)}>分享链接</Text>
              </View>
            </ContainerLayout>
          </View>
        
        )}
      />

     
    </View>
  )
  
}
house = forwardRef(house)
export default house